pub struct SidebarSection {
model: OnceCell<ListModel>,
inner_model: OnceCell<ListModel>,
filter: RoomCategoryFilter,
name: Cell<SidebarSectionName>,
display_name: PhantomData<String>,
is_empty: Cell<bool>,
is_expanded: Cell<bool>,
has_notifications: Cell<bool>,
notification_count: Cell<u64>,
is_read: Cell<bool>,
highlight: Cell<HighlightFlags>,
}Fields
model: OnceCell<ListModel>The source model of this section.
inner_model: OnceCell<ListModel>The inner model of this section.
filter: RoomCategoryFilterThe filter of this section.
name: Cell<SidebarSectionName>The name of this section.
display_name: PhantomData<String>The display name of this section.
is_empty: Cell<bool>Whether this section is empty.
is_expanded: Cell<bool>Whether this section is expanded.
has_notifications: Cell<bool>Whether any of the rooms in this section have unread notifications.
notification_count: Cell<u64>Total number of unread notifications over all the rooms in this section.
is_read: Cell<bool>Whether all the messages of all the rooms in this section are read.
highlight: Cell<HighlightFlags>The highlight state of the section.
Implementations
Sourceimpl SidebarSection
impl SidebarSection
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl SidebarSection
impl SidebarSection
Sourcefn update_notification_count_and_highlight(&self, model: &ExpressionListModel)
fn update_notification_count_and_highlight(&self, model: &ExpressionListModel)
Update each of the properties if needed and emit corresponding signals.
Sourcefn inner_model(&self) -> &ListModel
fn inner_model(&self) -> &ListModel
The inner model of this section.
Sourcefn set_name(&self, name: SidebarSectionName)
fn set_name(&self, name: SidebarSectionName)
Set the name of this section.
Sourcefn display_name(&self) -> String
fn display_name(&self) -> String
The display name of this section.
Sourcefn set_is_empty(&self, is_empty: bool)
fn set_is_empty(&self, is_empty: bool)
Set whether this section is empty.
Sourcefn set_is_expanded(&self, expanded: bool)
fn set_is_expanded(&self, expanded: bool)
Set whether this section is expanded.
Sourcefn session_settings(&self) -> Option<SessionSettings>
fn session_settings(&self) -> Option<SessionSettings>
The settings of the current session.